@@ -1,29 +1,31 @@
 # -*- coding: utf-8 -*-
+from typing import Union
 import DateTime
 import vobject
-from .date_time_tools import convert_datetime
-from .email_phone_tools import process_phonenumber
+from date_time_tools import convert_datetime
+from email_phone_tools import process_phonenumber
 
 comma_float_chars = set(',1234567890')
 datetime_chars = set('1234567890.-:/+ ')
 
 
-##  Create a dictionary from a list of dictionaries
-#
-#   @remark The annotated return type is not true if a single_value argument is given.
-#
-#   @param dictList: the list of dictionaries to be converted
-#   @param key: the key of the dictionaries to use as key for the new dictionary.
-#               This must be a unique key, otherwise the new dictionary will
-#               only contain the first result
-#   @param singleValue: only a single value for each key is provided
-#   @param include_key: the value used as key is also included in values dictionary
 def dict_from_dict_list(
     dict_list: list,
     key,
     single_value=None,
     include_key=False
 ) -> dict:
+    """Create a dictionary from a list of dictionaries
+
+    .. note:: The annotated return type is not true if a single_value argument is given.
+
+    :param dictList: the list of dictionaries to be converted
+    :param key: the key of the dictionaries to use as key for the new dictionary.
+                This must be a unique key, otherwise the new dictionary will
+                only contain the first result
+    :param singleValue: only a single value for each key is provided
+    :param include_key: the value used as key is also included in values dictionary
+    """
 
     dl = [dict(d) for d in dict_list]  # we copy the list because we will change the dictionaries (except for single_value)
 
@@ -41,26 +43,27 @@ def dict_from_dict_list(
     return new_dict
 
 
-##  Create a vCard
-#
-#   @remark The serialized vcard has Windows line-breaks,
-#           which is fine, I guess
-#   @remark colons in notes are escaped in vobject
-#
-#   @param data: keys:  - prename
-#                       - surname
-#                       - email
-#                       - phone
-#                       - street
-#                       - city
-#                       - region (eg. federal state)
-#                       - zipcode
-#                       - country
 def create_vcard(
     data: dict,
     returning: str = 'vcard'
-) -> 'vcard (str) or prettified vcard data':
-    "create a vCard from a dictionary"
+) -> str:
+    """create a vCard from a dictionary
+
+    .. note:: The serialized vcard has Windows line-breaks, which is fine, I guess
+    .. note:: colons in notes are escaped in vobject
+
+    :param data: keys:
+
+        - prename
+        - surname
+        - email
+        - phone
+        - street
+        - city
+        - region (eg. federal state)
+        - zipcode
+        - country
+    """
 
     prename = data.get('prename', '')
     surname = data.get('surname', '')
@@ -104,17 +107,18 @@ def create_vcard(
         return vcard.serialize()
 
 
-##  Converts all keys and values in a dictionary from bytes to unicode
-#
-#   All keys and values are changed from bytes to unicode, if applicable.
-#   Other data types are left unchaged, including other compound data types.
-#
-#  @param d: dictionary
-#  @param encoding: default is utf-8
 def dict_2unicode(
     d: dict,
     encoding: str = 'utf-8'
 ) -> dict:
+    """ Converts all keys and values in a dictionary from bytes to unicode
+
+    All keys and values are changed from bytes to unicode, if applicable.
+    Other data types are left unchaged, including other compound data types.
+
+    :param d: dictionary
+    :param encoding: default is utf-8
+    """
 
     return {
         k.decode(encoding) if isinstance(k, bytes) else k:
@@ -123,7 +127,6 @@ def dict_2unicode(
     }
 
 
-## convert all data of a dictionary to specific (json metadata) or guessed types
 def dict_2datatypes(
     d: dict,
     json_data: str = None,
@@ -131,6 +134,7 @@ def dict_2datatypes(
     convert_to_unicode: bool = False,
     dt: str = 'datetime'
 ) -> dict:
+    """ convert all data of a dictionary to specific (json metadata) or guessed types """
 
     if convert_keys:
         return {
@@ -160,16 +164,17 @@ def dict_2datatypes(
         }  # dict comprehension
 
 
-## Sorts a list of dictionaries
-#
-#  @param dictList: list of dictionaries
-#  @param keys: sort by these keys
-#  @param reverse: True reverses the sorting order
 def sort_dictlist(
     dictlist: list,
     keys: (str, list),
     reverse: bool = False
 ) -> list:
+    """ Sorts a list of dictionaries
+
+    :param dictList: list of dictionaries
+    :param keys: sort by these keys
+    :param reverse: True reverses the sorting order
+    """
 
     if isinstance(keys, str):
         if ',' in keys:
@@ -195,25 +200,28 @@ def sort_dictlist(
     return sorted_dictlist
 
 
-##  Convert a value to a datatype
-#
-#   this function has two modes:
-#   1. it uses a json file with the metadata (types of variables by name)
-#   2. it makes educated guesses in converting a string (don't feed bytes to this function!)
-#   @param value
-#   @param json_data: metadata
-#   @param key: key in the json_data (value name)
-#   @param convert_to_unicode: convert all bytes to unicode in the process
-#   @param encoding: if bytes are present, use this encoding to convert them to unicode
-#   @param dt: use datetime or DateTime as time format (default: datetime)
 def value_2datatype(
-    value: 'any type',
+    value,
     json_data: str = None,
-    key: (str, None) = None,
+    key: str = None,
     convert_to_unicode: bool = False,
     encoding: str = 'utf-8',
     dt: str = 'datetime'
-) -> 'converted or guessed type of "value"':
+) -> Union[str, int, float]:
+    """ Convert a value to a datatype
+
+    this function has two modes:
+
+    1. it uses a json file with the metadata (types of variables by name)
+    2. it makes educated guesses in converting a string (don't feed bytes to this function!)
+
+    :param value:
+    :param json_data: metadata
+    :param key: key in the json_data (value name)
+    :param convert_to_unicode: convert all bytes to unicode in the process
+    :param encoding: if bytes are present, use this encoding to convert them to unicode
+    :param dt: use datetime or DateTime as time format (default: datetime)
+    """
 
     if json_data:
         typ = json_data.get(key)
