@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
+from typing import Union
 import locale
 import pycountry
 from babel import Locale
 import gettext
 import holidays
 import datetime
+import DateTime
 from functools import lru_cache
 from babel.numbers import format_currency, get_territory_currencies
 
-from .text_name_tools import map_special_chars
-from .date_time_tools import convert_datetime
+from text_name_tools import map_special_chars
+from date_time_tools import convert_datetime
 
 countries = pycountry.countries
 keys_to_translate = ('name', 'official_name')
@@ -18,7 +20,9 @@ keys_to_translate = ('name', 'official_name')
 @lru_cache
 def get_locale(
     loc: locale = None
-):
+) -> dict:
+    """ Get system locale or transform locale provided as argument into a dictionary"""
+
     loc_dict = {}
 
     if not loc:
@@ -38,14 +42,15 @@ def get_locale(
     return loc_dict
 
 
-## Check if translation is needed
-#
-#  @param keys: keys that may need translation
-#  @param language: translate if language is not en
 def translation_needed(
     keys: (list, tuple),
     language: str
 ) -> bool:
+    """Check if translation is needed
+
+    :param keys: keys that may need translation
+    :param language: translate if language is not en
+    """
 
     trans_needed = False
 
@@ -57,28 +62,28 @@ def translation_needed(
     return trans_needed
 
 
-## Fetch all countries
-#
-# keys:
-# - alpha_2
-# - alpha_3
-# - name
-# - official_name
-# - numeric
-#
-# returning: tuple, list, dict, dictdict
-#
-# @param keys: default is ['alpha_2', 'name']
-# @param returning: list, tuple, dict, dictdict (dictionary of dictionaries) are possible
-# @param language: default is de
-# @param sort_key: name of the key
 @lru_cache
 def fetch_all_countries(
     keys: (list, tuple) = ['alpha_2', 'name'],
     returning: str = 'list',
     language: str = get_locale().get('language'),
     sort_key: str = 'name'
-) -> 'list, tuple, dict, dictdict (dictionary of dictionaries)':
+) -> (list, tuple, dict):
+    """Fetch all countries
+
+    :param keys: default is ['alpha_2', 'name'], possible values are:
+
+        - alpha_2
+        - alpha_3
+        - name
+        - official_name
+        - numeric
+
+    :param returning: list, tuple, dict, dictdict (dictionary of dictionaries) are possible
+    :param language: default is de
+    :param sort_key: name of the key
+    :raises ValueError: if sort_key is not in keys
+    """
 
     get_translation = translation_needed(
         keys=keys,
@@ -192,16 +197,16 @@ def format_price(
     return price_str.replace('\xa0', ' ')
 
 
-## Get country
-#
-# Return all the data for a country
-# returns a dictionary
 @lru_cache(maxsize=5)
 def get_country(
     country: str = get_locale().get('country'),
     key: str = 'alpha_2',
     language: str = get_locale().get('language')
 ) -> dict:
+    """Get country
+
+    Return all the data for a country
+    """
 
     country = country.upper()  # otherwise babel Locale won't work
 
@@ -225,35 +230,19 @@ def get_country(
     return countryDict
 
 
-## Get language name
-#
-# @param language is the language in which the language name is returned
 @lru_cache(maxsize=5)
 def get_language_name(
     code: str = get_locale().get('language'),
     language: str = get_locale().get('language')
 ) -> str:
+    """Get language name
+
+    :param language: is the language in which the language name is returned
+    """
 
     return Locale(code).get_language_name(language)
 
 
-##  Fetch holidays
-#
-#   @param years
-#   @param length: maximum to return, mit length kann man die Anzahl begrenzen
-#   @param daterange
-#   @param fmt: default: %d.%m.%Y
-#   @param bundesland: default: Wien
-#   @param datatype: default: date
-#   @param state: this argument exists only for the sake of convenience. It actually feeds subdiv
-#                 but "state" is more intuitive as a name for most countries
-#   @param returning: values
-#     - dict, dictionary (default): keys as specified in argument datatype
-#     - holidays: return the holidays data object
-#     - days, dates: return only the dates, as specified in argument datatype
-#     - names: only the names of the holidays, sorted chronologically
-#     - names_sorted: only the names of the holidays, sorted alphabetically
-#     - tuples
 def fetch_holidays(
     country: str = get_locale().get('country'),
     state: (str, int) = None,
@@ -264,7 +253,27 @@ def fetch_holidays(
     fmt: str = None,
     datatype: str = 'date',
     returning: str = 'dictionary'
-) -> (list, dict):
+) -> Union[list, dict]:
+    """Fetch holidays
+
+    :param years:
+    :param length: maximum to return, mit length kann man die Anzahl begrenzen
+    :param daterange:
+    :param fmt: default: %d.%m.%Y
+    :param datatype: default: date
+    :param state: this argument exists only for the sake of convenience. It actually feeds subdiv but "state" is more intuitive as a name for most countries
+    :param returning: values
+
+        - dict, dictionary (default): keys as specified in argument datatype
+        - holidays: return the holidays data object
+        - days, dates: return only the dates, as specified in argument datatype
+        - names: only the names of the holidays, sorted chronologically
+        - names_sorted: only the names of the holidays, sorted alphabetically
+        - tuples
+
+    :raises Exception: for unknown value for argument "returning"
+    :raises Exception: for datatype "DateTime" and returning "holidays"
+    """
 
     country = country.upper()
 
@@ -379,11 +388,6 @@ def fetch_holidays(
         )
 
 
-##  Check if date is a holiday
-#
-#   @param datum
-#   @param fmt
-#   @param state = subdiv
 def is_holiday(
     datum: (
         str,
@@ -396,6 +400,12 @@ def is_holiday(
     state: (str, int) = None,
     subdiv: (str, int) = None,
 ) -> bool:
+    """Check if date is a holiday
+
+    :param datum:
+    :param fmt:
+    :param state: subdiv
+    """
 
     country = country.upper()
 
