@@ -39,12 +39,14 @@ char_nb_map = {
 }
 
 
-# creates a human-readable list, including "and"
-# (or any similar word, i.e. in another language)
 def and_list(
     elements: list,
     et: str = 'and'
 ) -> str:
+    """ creates a human-readable list, including "and"
+    (or any similar word, i.e. in another language)
+    """
+
     elements = [str(el) for el in elements]
     return re.sub(r', (\w+)$', r' {} \1'.format(et), ', '.join(elements))
 
@@ -60,33 +62,37 @@ NAME_PREFIXES = (
 )
 
 
-#   Capitalize text or names
-#
-#   This is specially handy for names which otherwise
-#   would be capitalized wrongly with string's "title"
-#   method like:
-#   - Conan McArthur
-#   - Susanne Mayr-Grünwald
-#   - Maria de Angelis
-def capitalize_text(
-    text: str,
-    name: bool = False
+def capitalize_name(
+    text: str
 ) -> str:
-    words = text.split()  # splits only at spaces
+    """ Capitalize name
 
-    if not name:
-        return text.title()
+    This is specially handy for names which otherwise
+    would be capitalized wrongly with string's "title"
+    method like:
+
+       - Conan McArthur
+       - Susanne Mayr-Grünwald
+       - Maria de Angelis
+
+    """
+
+    words = text.split()  # splits only at spaces
 
     new_words = []
 
     for word in words:
-        if word.lower().startswith('mac'):
-            word = 'Mac' + word[len('Mac'):].capitalize()
-        elif name and word.lower() in NAME_PREFIXES:
+        if '-' in word:
+            word = '-'.join([w.title() for w in word.split('-')])
+        elif word.lower() in NAME_PREFIXES:
             pass
         else:
             word = word[0].upper() + word[1:].lower()
 
+        for mac in ('mac', 'mc'):
+            if word.lower().startswith(mac):
+                word = mac.capitalize() + word[len(mac):].capitalize()
+
         new_words.append(word)
 
     return ' '.join(new_words)
@@ -97,10 +103,6 @@ def get_gender(prename: str) -> str:
     return d.get_gender(prename)
 
 
-##  Leet a string
-#
-#   leet any string
-#   @param symbol_chance: 1 out of n that a random symbol will be added
 def leet(
     text: str,
     max_length: int = None,
@@ -108,6 +110,12 @@ def leet(
     symbol_chance: int = 0,
     start_at_begin: bool = True
 ) -> str:
+    """ Leet a string
+
+    leet any string
+
+    :param symbol_chance: 1 out of n that a random symbol will be added
+    """
 
     text = unidecode.unidecode(text).lower()  # remove Umlaute
 
@@ -139,19 +147,23 @@ def leet(
     return leeted_text
 
 
-##  Sort names
-#
-#   Sorts by name, prename: splits only at the last space before sorting
-#
-#   Correctly sorts names
-#   - with special characters, like umlauts
-#   - combined names
-#   - names with prefixes (like de or von)
-#
-#   examples:
-#   - Susanne Mayr-Grünwald
-#   - Maria de Angelis
 def sort_names(names: list) -> list:
+    """ Sort names
+
+    Sorts by name, prename: splits only at the last space before sorting
+
+    Correctly sorts names
+
+        - with special characters, like umlauts
+        - combined names
+        - names with prefixes (like de or von)
+
+    examples:
+
+        - Susanne Mayr-Grünwald
+        - Maria de Angelis
+    """
+
     name_dict = {}
 
     for name in names:
@@ -175,15 +187,16 @@ def sort_names(names: list) -> list:
     return sorted_list
 
 
-##  map special characters
-#
-#   @param sort: case is preserved in any case. If you want lowercase, you have to feed
-#                the function appropriately.
-#                If sort is set to True, all character lengths are preserved.
 def map_special_chars(
     text: str,
     sort: bool = False
 ) -> str:
+    """ map special characters
+
+    :param sort: case is preserved in any case. If you want lowercase, you have to feed
+                 the function appropriately.
+                 If sort is set to True, all character lengths are preserved.
+    """
 
     intab = 'AAAÁÀÂÃ?aaaáàâãå?CCCCccccçDÐddEEEEEÉÈÊËeeeeeéèêëGGggÍÌÎÏíìîïÓÒÔóòôõøñÚÙÛúùûÝýÿ'
 
