@@ -12,7 +12,7 @@ import DateTime
 sys.path.append(".")
 
 from locales_tools import \
-    fetch_holidays, is_holiday
+    fetch_holidays, is_holiday, format_price
 
 days_and_holidays = {
     '1.4.2020': False,
@@ -91,9 +91,13 @@ class TestLocales(unittest.TestCase):
 
     def test_is_holiday(self):
         for date, check in days_and_holidays.items():
-            checked = is_holiday(datum=date)
+            checked = is_holiday(datum=date, country='AT', state=9)
             self.assertEqual(checked, check)
 
+    def test_format_price(self):
+        for price in (123, 2, 234234, 234100):
+            print(format_price(price))
+
 
 if __name__ == '__main__':
     unittest.main()
