@@ -11,7 +11,7 @@ import random
 sys.path.append(".")
 
 from text_name_tools import \
-    and_list, leet, capitalize_text, sort_names, get_gender
+    and_list, leet, capitalize_name, sort_names, get_gender
 
 names = {
     'Georg Pfolz': {
@@ -82,20 +82,12 @@ class TestTextName(unittest.TestCase):
 
         # because of the use of random, using Asserts does not make any sense here
 
-    def test_capitalize_text(self):
-        lowercase_names = [
-            v.get('lowercase') for v in names.values()
-        ]
-
-        for name in lowercase_names:
-            capitalized_name = capitalize_text(text=name, name=True)
-            print(f'{name} --> {capitalized_name}')
-
-        capitalized_text = capitalize_text(text=lower_text)
-        print(f'Cap Text: {capitalized_text}')
+    def test_capitalize_name(self):
+        for name, name_dict in names.items():
+            capitalized_name = capitalize_name(text=name_dict.get('lowercase'))
+            self.assertEqual(name, capitalized_name)
 
     def test_get_gender(self):
-
         for name, name_dict in names.items():
             correct_gender = name_dict.get('gender')
             gender = get_gender(name.split()[0])  # prename
